ConstrainedScrollView class

A constrained box in which a single widget can be scrolled.

It's combination of SingleChildScrollView and LayoutBuilder. ConstrainedScrollView includes all configuration of those widgets.

Inheritance

Constructors

ConstrainedScrollView({Axis scrollDirection = Axis.vertical, bool reverse = false, EdgeInsetsGeometry padding = EdgeInsets.zero, bool? primary, ScrollPhysics? physics, ScrollController? controller, DragStartBehavior dragStartBehavior = DragStartBehavior.start, Clip clipBehavior = Clip.hardEdge, String? restorationId, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, BoxConstraintsBuilder? constraintsBuilder, Widget? child, Key? key})
A constrained box in which a single widget can be scrolled.
const

Properties

child Widget?
final
clipBehavior Clip
Defaults to Clip.hardEdge.
final
constraintsBuilder BoxConstraintsBuilder?
Builder for the constraints to impose on the ConstrainedScrollView's child.
final
controller ScrollController?
final
dragStartBehavior DragStartBehavior
Defaults to DragStartBehavior.start.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardDismissBehavior ScrollViewKeyboardDismissBehavior
Defaults to ScrollViewKeyboardDismissBehavior.manual.
final
padding EdgeInsetsGeometry
Defaults to EdgeInsets.zero.
final
physics ScrollPhysics?
final
primary bool?
final
restorationId String?
final
reverse bool
Defaults to false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection Axis
Defaults to Axis.vertical.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited